@@ -357,6 +357,7 @@ DLL_EXPORT int get_state_variable_array(
     - `"U_superficial"`: Superficial Velocity [m/s]
     - `"RS"`: Gas mass fraction in gas/oil mixture [kg/kg]
     - `"RSW"`: Water vapour mass fraction in gas phase [kg/kg]
+    - `"S_w"`: Wetted Perimeter of a layer [m]
     - `"ff_S_wall"`: Wall friction factor times wall perimeter [-]
     - `"ff_S_interface"`: Interface Friction factor times interface perimeter [-]
     - `"D"`: Pipe Inner Diameter [m]
@@ -438,6 +439,9 @@ DLL_EXPORT int get_simulation_tracer_array(
     @param[in] ts_scope #TimestepScope value.
     @param[in] variable_name_c String with the variable name. See the list of possible values above.
     @return An #error_code value.
+
+    It is important to know that `dt` may have value equal to `NAN` (Not a number) during the steady
+    state simulation. In this case the plugin must handle it and not use this value.
 */
 DLL_EXPORT int get_simulation_quantity(
     void* ctx,
@@ -472,6 +476,34 @@ DLL_EXPORT int get_flow_pattern(
     int* size
 );
 
+/*!
+    Gets the liquid-liquid flow pattern for each control volume. Related to the UCM
+    liquid-liquid system.
+
+    List of possible values of `Liquid-Liquid Flow Pattern` is:
+    - `0 - Unknown`: Unknown Flow Pattern.
+    - `1 - Ambivalent`: Ambivalent Flow Pattern between Dispersed Oil and Dispersed Water.
+    - `2 - Dispersed Oil`: Dispersed oil in continuous water.
+    - `3 - Dispersed Water`: Dispersed water in continuous Oil.
+    - `4 - Separated`: Separated continuous oil and continuous water.
+    - `5 - Separated Mixed`: Separated with dispersed oil and water droplets.
+    - `6 - Separated Wavy`: Separated with waves.
+
+    @param[in] ctx ALFAsim's plugins context.
+    @param[out] out Liquid-Liquid Flow Pattern values array. See list of possible values above.
+    @param[in] grid_scope A #GridScope value.
+    @param[in] ts_scope A #TimestepScope value.
+    @param[in] size Size of out array of values.
+    @return An #error_code value.
+*/
+DLL_EXPORT int get_liqliq_flow_pattern(
+    void* ctx,
+    int** out,
+    enum GridScope grid_scope,
+    enum TimestepScope ts_scope,
+    int* size
+);
+
 /*!
     Retrieves the tracer ID given a tracer reference. A tracer reference may be obtained from the
     user input data (See #get_plugin_input_data_reference API function for an example).
@@ -579,7 +611,8 @@ DLL_EXPORT int get_wall_interfaces_temperature(
     - `"U"`: Velocity [m/s]
 
     It is important to know that the listed `variable_name`s are not available in any phase, only for
-    two phase systems, in which `Gas id` is 0 (zero) and `Liquid id` (sum of all liquid phases) is 1 (One).
+    two phase systems, in which `GAS` (0, zero) and `LIQUID` (1, One)(sum of all liquid phases) are
+    the possible values, and they are available in the #TwoPhaseSystem enumeration.
     Because of that, the #error_code must be checked.
 
     List of `variable_name` with one value:
@@ -629,4 +662,120 @@ DLL_EXPORT int get_ucm_fluid_geometrical_properties(
     double D
 );
 
+/*!
+    Gets the current control volume input data for liquid-liquid flow Pattern calculation.
+    Any available variable by this function is considered for a control volume, which
+    means that there are variables with one value and there are variables with two values
+    related to the liquid-liquid system (OIL and WATER).
+    If a given variable name is not available, a #NOT_AVAILABLE_DATA error is returned.
+
+    List of `variable_name` with two values (Oil and Water):
+    - `"rho"`: Density [kg/m3]
+    - `"mu"`: Viscosity [Pa.s]
+    - `"U_S"`: Superficial Velocity [m/s]
+
+    It is important to know that the listed `variable_name`s are not available in any phase, only for
+    liquid-liquid systems, in which `OIL` (0, zero) and `WATER` (1, One) are the possible values, and
+    they are available in the #LiquidLiquidSystem enumeration.
+    Because of that, the #error_code must be checked.
+
+    List of `variable_name` with one value:
+    - `"D_h"`: Unit Cell Liquid (Oil-Water) Hydraulic Diameter [m]
+    - `"ks"`: Absolute Roughness [m]
+    - `"theta"`: Inclination of the Unit Cell [rad]
+    - `"sigma"`: Liquid-liquid (Oil-Water) Surface Tension [N/m]
+
+    @param[in] ctx ALFAsim's plugins context.
+    @param[out] out Variable value.
+    @param[in] var_name String with the variable name. See the list of possible values above.
+    @param[in] phase_id A #LiquidLiquidSystem value. When the requested variable is not associated
+                            to a phase any value can be passed.
+    @return An #error_code value.
+*/
+DLL_EXPORT int get_liq_liq_flow_pattern_input_variable(
+    void* ctx, double* out, const char* var_name, int phase_id
+);
+
+/*!
+    Gets the current input data for liquid effective viscosity calculation. Any available variable by
+    this function is considered for a control volume, which means that there are variables with one
+    value and there are variables with two values related to the liquid-liquid system (OIL and WATER).
+    If a given variable name is not available, a #NOT_AVAILABLE_DATA error is returned.
+
+    List of `variable_name` with two values (Oil and Water):
+    - `"rho"`: Density [kg/m3]
+    - `"mu"`: Viscosity [Pa.s]
+    - `"U_S"`: Superficial Velocity [m/s]
+
+    It is important to know that the listed `variable_name`s are not available in any phase, only for
+    liquid-liquid systems, in which `OIL` (0, zero) and `WATER` (1, One) are the possible values, and
+    they are available in the #LiquidLiquidSystem enumeration.
+    Because of that, the #error_code must be checked.
+
+    List of `variable_name` with one value:
+    - `"alpha_w"` : Water Volume Fraction [m3 of `water phase` / m3 of `liquid(Oil+Water) phase`]
+    - `"D_h"`: Unit Cell Liquid (Oil-Water) Hydraulic Diameter [m]
+    - `"ks"`: Absolute Roughness [m]
+    - `"theta"`: Inclination of the Unit Cell [rad]
+    - `"sigma"`: Liquid-liquid (Oil-Water) Surface Tension [N/m]
+
+    @param[in] ctx ALFAsim's plugins context.
+    @param[out] out Variable value.
+    @param[in] var_name String with the variable name. See the list of possible values above.
+    @param[in] phase_id A #LiquidLiquidSystem value. When the requested variable is not associated
+                            to a phase any value can be passed.
+    @return An #error_code value.
+*/
+DLL_EXPORT int get_liquid_effective_viscosity_input_variable(
+    void* ctx, double* out, const char* var_name, int phase_id
+);
+
+/*!
+    Gets the current input data for Gas-Liquid surface tension calculation. Any available variable by
+    this function is considered for a control volume, which means that there are variables with one
+    value and there are variables with two values related to the liquid-liquid system (OIL and WATER).
+    If a given variable name is not available, a #NOT_AVAILABLE_DATA error is returned.
+
+    List of `variable_name` with two values (Oil and Water):
+    - `"sigma_gll"`: Gas-Liquid-Liquid (Gas-Oil or Gas-Water) Surface Tension [N/m]
+
+    It is important to know that the listed `variable_name`s are not available in any phase, only for
+    liquid-liquid systems, in which `OIL` (0, zero) and `WATER` (1, One) are the possible values, and
+    they are available in the #LiquidLiquidSystem enumeration.
+    Because of that, the #error_code must be checked.
+
+    List of `variable_name` with one value:
+    - `"alpha_w"` : Water Volume Fraction [m3 of `water phase` / m3 of `liquid(Oil+Water) phase`]
+
+    @param[in] ctx ALFAsim's plugins context.
+    @param[out] out Variable value.
+    @param[in] var_name String with the variable name. See the list of possible values above.
+    @param[in] phase_id A #LiquidLiquidSystem value. When the requested variable is not associated
+                            to a phase any value can be passed.
+    @return An #error_code value.
+*/
+DLL_EXPORT int get_gas_liq_surface_tension_input_variable(
+    void* ctx, double* out, const char* var_name, int phase_id
+);
+
+/*!
+    Gets the current input data for Shear force calculation. Any available variable by this function
+    is considered for a control volume, which means that there are variables with one value and there
+    are variables with two values related to the liquid-liquid system (OIL and WATER).
+    If a given variable name is not available, a #NOT_AVAILABLE_DATA error is returned.
+
+    The variables available are the same as #get_liq_liq_flow_pattern_input_variable and
+    its documentation should be visited for more details.
+
+    @param[in] ctx ALFAsim's plugins context.
+    @param[out] out Variable value.
+    @param[in] var_name String with the variable name. See the list of possible values above.
+    @param[in] phase_id A #LiquidLiquidSystem value. When the requested variable is not associated
+                            to a phase any value can be passed.
+    @return An #error_code value.
+*/
+DLL_EXPORT int get_liq_liq_shear_force_per_volume_input_variable(
+    void* ctx, double* out, const char* var_name, int phase_id
+);
+
 #endif
